#' Data matrix p by n 
'x' 
#' The vector of class indicators 
'group'
#' A list of KEGG pathways
'pathways'
#' A data frame of edges, each row corresponding to one edge
'edgelist'
#' A data frame of nonedges, each row corresponding to one negative edge
'nonedgelist'
#' Matrix with pathway indicators
'pathways_mat'
    